import 'dart:ui';

import 'package:cached_network_marker/src/params/params.dart';
import 'package:flutter/foundation.dart';
import 'package:freezed_annotation/freezed_annotation.dart';

part 'circle_avatar_params.freezed.dart';

/// Immutable parameters holder for circle avatar marker.
@freezed
class CircleAvatarParams with _$CircleAvatarParams {
  /// Creates new parameter holder.
  @Assert('radius > 0')
  @Assert('borderWidth > 0')
  @Assert('dotRadius > 0')
  @Assert('spacing > 0')
  @Assert('radius > borderWidth')
  @Assert('radius > dotRadius')
  const factory CircleAvatarParams({
    /// Color of the marker border. It will be applied to the border of the circle avatar and the dot below.
    required Color color,

    /// Radius of the circle avatar. Containing border width.
    @Default(30) int radius,

    /// Border width of the circle avatar.
    @Default(4) int borderWidth,

    /// Radius of dot below the circle avatar.
    @Default(6) int dotRadius,

    /// Spacing between the dot and the circle avatar.
    @Default(4) int spacing,
  }) = _CircleAvatarParams;

  /// Private constructor for enabling custom getter on class generated by freezed package.
  const CircleAvatarParams._();

  /// Generates the prefix for cache key of the marker.
  String get keyPrefix {
    final typeStr = enumToString(MarkerType.circleAvatar);
    return 'type=$typeStr&r=$radius&bw=$borderWidth&dr=$dotRadius&s=$spacing';
  }
}
